from setuptools import setup

setup(name='cauldron',
      version='1.0.8',
      author='Ankit Chandawala',
      author_email='ankitchandawala@gmail.com',
      url='https://github.com/nerandell/cauldron',
      description='Utils to reduce boilerplate code',
      packages=['cauldron'], install_requires=['aiopg'])
